..
   Copyright (C) 2024 Roberto Rossini <roberros@uio.no>
   SPDX-License-Identifier: MIT

Python API Reference
####################

hictkpy API is structured as follows:

.. toctree::
   :maxdepth: 1

   generic
   cooler
   hic
